@@ -20,7 +20,17 @@ sub preload {
 sub load_app {
     my($class, $app) = @_;
     return $apps{$app} ||= do {
-        local $ENV{MOD_PERL}; # trick Catalyst/CGI.pm etc.
+        # Trick Catalyst, CGI.pm, CGI::Cookie and others that check
+        # for $ENV{MOD_PERL}.
+        #
+        # Note that we delete it instead of just localizing
+        # $ENV{MOD_PERL} because some users may check if the key
+        # exists, and we do it this way because "delete local" is new
+        # in 5.12:
+        # http://perldoc.perl.org/5.12.0/perldelta.html#delete-local
+        local $ENV{MOD_PERL};
+        delete $ENV{MOD_PERL};
+
         Plack::Util::load_psgi $app;
     };
 }
